@@ -444,6 +444,9 @@ setMethodS3("setCdf", "AffymetrixCelSet", function(this, cdf, verbose=FALSE, ...
 
 setMethodS3("findByName", "AffymetrixCelSet", function(static, ..., chipType=NULL, paths=c("rawData/", "probeData/")) {
   # Arguments 'chipType':`
+  if (!is.null(chipType)) {
+    chipType <- Arguments$getCharacter(chipType);
+  }
 
   # Arguments 'paths':
   if (is.null(paths)) {
@@ -451,7 +454,7 @@ setMethodS3("findByName", "AffymetrixCelSet", function(static, ..., chipType=NUL
   }
 
   # NextMethod() does not work here.
-  findByName.GenericDataFileSet(static, ..., subdirs=chipType, paths=paths); 
+  findByName.GenericDataFileSet(static, ..., subdirs=chipType, paths=paths);
 }, static=TRUE)
 
 
@@ -464,25 +467,38 @@ setMethodS3("fromName", "AffymetrixCelSet", function(static, ...) {
 
 
 setMethodS3("byName", "AffymetrixCelSet", function(static, name, tags=NULL, chipType=NULL, cdf=NULL, paths=NULL, ...) {
+  # Argument 'chipType':
+  if (!is.null(chipType)) {
+    chipType <- Arguments$getCharacter(chipType);
+  }
+
   # Argument 'cdf':
   if (!is.null(cdf)) {
     cdf <- Arguments$getInstanceOf(cdf, "AffymetrixCdfFile");
   }
 
-  # Argument 'chipType':
-  if (is.null(chipType)) {
-    if (!is.null(cdf)) {
-      chipType <- getChipType(cdf, fullname=FALSE);  # Without tags
-    } else {
-      throw("Argument 'chipType' must be specified unless argument 'cdf' is specified.");
-    }
+  if (is.null(cdf) && is.null(chipType)) {
+    throw("Either argument 'chipType' or argument 'cdf' must be specified.");
   }
 
+#  if (!is.null(cdf) && !is.null(chipType)) {
+#    throw("Only one of argument 'chipType' and argument 'cdf' can be specified.");
+#  }
+
+  # If argument 'cdf' is not specified, infer it from 'chipType'.
+  if (is.null(cdf)) {
+    cdf <- AffymetrixCdfFile$byChipType(chipType);
+  }
+
+  # The chiptype without tags
+  chipTypeShort <- getChipType(cdf, fullname=FALSE);
+
   suppressWarnings({
-    path <- findByName(static, name, tags=tags, chipType=chipType, paths=paths, ...);
+    path <- findByName(static, name, tags=tags, 
+                       chipType=chipTypeShort, paths=paths, ...);
   })
   if (is.null(path)) {
-    path <- file.path(paste(c(name, tags), collapse=","), chipType);
+    path <- file.path(paste(c(name, tags), collapse=","), chipTypeShort);
     throw("Cannot create ", class(static)[1], ".  No such directory: ", path);
   }
 
@@ -1101,299 +1117,6 @@ setMethodS3("readUnits", "AffymetrixCelSet", function(this, units=NULL, ..., for
 })
 
 
-###########################################################################/**
-# @RdocMethod getAverageFile
-#
-# @title "Calculates the mean and the standard deviation of the cell signal (intensity, standard deviation etc.) across the CEL set"
-#
-# \description{
-#   @get "title".
-# }
-#
-# @synopsis
-#
-# \arguments{
-#  \item{name}{The label of the calculated parameters.
-#    If @NULL, a default name format \code{<prefix>-<mean>-<sd>} is used.}
-#  \item{indices}{An @integer @vector specifying which cells to consider.
-#    If \code{"remaining"}, only parameters for cells that have not been
-#    are calculated.
-#    If @NULL, all cells are used.}
-#  \item{mean}{A @character of a @function specifying the function used
-#    to calculate the average.}
-#  \item{sd}{A @character of a @function specifying the function used
-#    to calculate the standard deviation.}
-#  \item{na.rm}{If @TRUE, @NAs are excluded before, otherwise not.}
-#  \item{...}{Not used.}
-#  \item{cellsPerChunk}{A @integer specifying the total number of cells 
-#    (across arrays) read into memory per chunk.}
-#  \item{moreCells}{A @double scalar indicating if more or less cells
-#    should be used per chunk.}
-#  \item{force}{If @TRUE, parameters for cells already calculated are
-#    recalculated, otherwise not.}
-#  \item{verbose}{If @TRUE, progress details are printed, otherwise not.
-#    May also be a @see "R.utils::Verbose" object.}
-# }
-#
-# \value{
-#   Returns an @see "AffymetrixCelSet" of the same class as the CEL set
-#   averaged.
-# }
-#
-# \details{
-#   The parameter estimates are stored as a CEL file of the same class as
-#   the data files in the set.  The CEL file is named \code{<name>.cel}
-#   and placed in the directory of the set.
-#   Currently there is no specific data class for this file, but the average
-#   cell signals are stored as "intensities", the standard deviation of the
-#   cell signals as "stddevs", and the number of data points used for each
-#   estimate is stored as "pixels".
-# }
-#
-# @author
-#
-# \seealso{
-#   @seeclass
-# }
-#*/###########################################################################
-setMethodS3("getAverageFile", "AffymetrixCelSet", function(this, name=NULL, prefix="average", indices="remaining", field=c("intensities", "stdvs"), mean=c("median", "mean"), sd=c("mad", "sd"), na.rm=TRUE, g=NULL, h=NULL, ..., cellsPerChunk=moreCells*10^7/length(this), moreCells=1, force=FALSE, verbose=FALSE) {
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Argument 'field':
-  field <- match.arg(field);
-  
-  # Argument 'mean':
-  if (is.character(mean)) {
-    mean <- match.arg(mean);
-    meanName <- mean;
-    if (mean == "mean") {
-      mean <- base::rowMeans;
-    } else if (mean == "median") {
-      mean <- rowMedians;
-    }
-  } else if (is.function(mean)) {
-    meanName <- "customMean";
-  } else {
-    throw("Argument 'mean' must be either a character or a function: ", mode(mean));
-  }
-
-  # Argument 'sd':
-  if (is.character(sd)) {
-    sd <- match.arg(sd);
-    sdName <- sd;
-    if (sd == "sd") {
-      sd <- rowSds;
-    } else if (sd == "mad") {
-      sd <- rowMads;
-    }
-  } else if (is.function(sd)) {
-    sdName <- "customSd";
-  } else {
-    throw("Argument 'sd' must be either a character or a function: ", 
-                                                           mode(sd));
-  }
-
-  # Argument 'name':
-  if (is.null(name)) {
-    key <- list(method="getAverageFile", class=class(this)[1], 
-                arrays=sort(getNames(this)), mean=meanName, sd=sdName);
-    # assign mean and sd to an empty environment so that digest() doesn't
-    # pick up any "promised" objects from the original environment.
-    # A bit ad hoc, but it works for now. /2007-01-03
-    key <- base::lapply(key, FUN=function(x) {
-      if (is.function(x))
-        environment(x) <- emptyenv();
-      x;
-    })
-    id <- digest2(key);
-    name <- sprintf("%s-%s-%s-%s,%s", prefix, field, meanName, sdName, id);
-
-    # Save for troubleshooting inconsistency(?) in digest()/Rv2.6.0?!?
-    # /HB 2007-08-30
-    idPath <- getCachePath(c("aroma.affymetrix", "idChecks"));
-    idPathname <- file.path(idPath, id);
-    saveObject(list(key=key, keyIds=lapply(key, digest2), id=id), idPathname);
-  }
-
-  # Argument 'indices':
-  df <- as.list(this)[[1]];
-  nbrOfCells <- getHeader(df)$total;
-  if (force) {
-    if (identical(indices, "remaining")) {
-      indices <- NULL;
-    }
-  }
-
-  if (is.null(indices)) {
-    indices <- 1:nbrOfCells; 
-  } else if (identical(indices, "remaining")) {
-  } else {
-    indices <- Arguments$getIndices(indices, max=nbrOfCells);
-  }
-
-  # Argument 'cellsPerChunk':
-  cellsPerChunk <- Arguments$getInteger(cellsPerChunk, range=c(1,Inf));
-
-  # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
-  if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
-  }
-
-
-  verbose && enter(verbose, "Retrieving average cell signals across ", length(this), " arrays");
-
-
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Create CEL file to store the average array
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Create a private filename (with a dot prefix) to make sure it is not
-  # identified as a regular CEL file when the directory is scanned for files.
-  filename <- sprintf(".%s.CEL", name);
-  if (is.null(this$.averageFiles))
-    this$.averageFiles <- list();
-  res <- this$.averageFiles[[filename]];
-
-  # Has file been deleted since last time?
-  if (!is.null(res) && !isFile(res)) {
-    warning("Will recalculate average file, because it seems to have been deleted since last time: ", getPathname(res));
-    res <- NULL;
-  }
-
-  if (is.null(res)) {
-    verbose && enter(verbose, "Creating CEL file to store average signals");
-    verbose && cat(verbose, "Pathname: ", file.path(getPath(this), filename));
-    res <- createFrom(df, filename=filename, path=getPath(this), methods="create", clear=TRUE, verbose=less(verbose));
-    verbose && exit(verbose);
-    this$.averageFiles[[filename]] <- res;
-  }
-
-  verbose && print(verbose, res);
-
-  pathname <- getPathname(res);
-
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Identify which indices to use
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  if (identical(indices, "remaining")) {
-    pixels <- readCel(pathname, readIntensities=FALSE, readStdvs=FALSE, 
-                      readPixels=TRUE)$pixels;
-    indices <- which(pixels == 0);
-    rm(pixels); # Not needed anymore.
-  }
-
-  nbrOfIndices <- length(indices);
-
-  # Nothing more to do?
-  if (nbrOfIndices == 0)
-    return(res);
-
-  verbose && cat(verbose, "Number of cells to be updated: ", nbrOfIndices);
-
-
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Estimate the mean and standard deviation
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Since we might want to do this robustly, but also because we want to
-  # estimate the standard deviation, for each cell we need all data across 
-  # arrays at once.  In order to this efficiently, we do this in chunks
-  idxs <- 1:nbrOfIndices;
-  head <- 1:cellsPerChunk;
-  nbrOfChunks <- ceiling(nbrOfIndices / cellsPerChunk);
-  verbose && cat(verbose, "Number cells per chunk: ", cellsPerChunk);
-
-  # Get the pathnames of all CEL files to average
-  pathnames <- lapply(this, getPathname);
-  pathnames <- unlist(pathnames, use.names=FALSE);
-  nbrOfArrays <- length(pathnames);
-
-  if (!na.rm)
-    n <- rep(nbrOfArrays, length=cellsPerChunk);
-  count <- 1;
-  while (length(idxs) > 0) {
-    verbose && enter(verbose, "Fitting chunk #", count, " of ", nbrOfChunks);
-    if (length(idxs) < cellsPerChunk) {
-      head <- 1:length(idxs);
-      if (!na.rm)
-        n <- rep(nbrOfArrays, length=length(idxs));
-    }
-
-    # The indices to be used in this chunk
-    ii <- idxs[head];
-    verbose && cat(verbose, "Chunk size: ", length(ii));
-
-    verbose && enter(verbose, "Reading data");
-#    X <- readCelIntensities(pathnames, indices=indices[ii]);
-    readIntensities <- (field == "intensities");
-    readStdvs <- (field == "stdvs");
-    # TODO: Ideally, affxparser::readCel() should support 
-    # multiple filenames turning every data fields into a 
-    # matrix. /HB 2007-01-07
-    X <- matrix(as.double(NA), nrow=length(ii), ncol=nbrOfArrays);
-    for (kk in seq(length=nbrOfArrays)) {
-      X[,kk] <- readCel(filename = pathnames[kk],
-                        indices = indices[ii],
-                        readIntensities = readIntensities,
-                        readHeader = FALSE,
-                        readStdvs = readStdvs,
-                        readPixels = FALSE,
-                        readXY = FALSE,
-                        readOutliers = FALSE,
-                        readMasked = FALSE,
-                        ...,
-                        verbose = (verbose - 1))[[field]];
-    }
-    verbose && exit(verbose);
-
-    if (!is.null(g)) {
-      verbose && enter(verbose, "Transforming data using y = g(x)");
-      X <- g(X);
-      verbose && exit(verbose);
-    }
-
-    verbose && enter(verbose, "Estimating averages and standard deviations");
-    if (na.rm)
-      n <- base::apply(X, MARGIN=1, FUN=function(x) { sum(!is.na(x)) });
-
-    # Calculate the mean signal    
-    mu <- mean(X, na.rm=na.rm);          # Special mean()!
-    # Calculate the standard deviation of the signals
-    sigma <- sd(X, mean=mu, na.rm=na.rm);   # Special sd()!
-
-    verbose && exit(verbose);
-
-    if (!is.null(h)) {
-      verbose && enter(verbose, "Back-transforming estimates using x = h(y)");
-      mu <- h(mu);
-      sigma <- h(sigma);
-      verbose && exit(verbose);
-    }
-
-    # Write estimates to result file
-    verbose && enter(verbose, "Writing estimates");
-    updateCel(pathname, indices=indices[ii], intensities=mu, stdvs=sigma, pixels=n);
-    verbose && exit(verbose);
-
-    # Not needed anymore
-    mu <- sigma <- NULL;
-
-    # Next chunk...
-    idxs <- idxs[-head];
-    count <- count + 1;
-
-    # Garbage collection
-    gc();
-    verbose && exit(verbose);
-  } # while()
-
-  verbose && exit(verbose);
-
-  res;  
-})
-
-
 setMethodS3("getAverage", "AffymetrixCelSet", function(this, ...) {
   getAverageFile(this, ...);
 })
@@ -1448,6 +1171,10 @@ setMethodS3("getUnitGroupCellMap", "AffymetrixCelSet", function(this, ...) {
 
 ############################################################################
 # HISTORY:
+# 2010-07-02
+# o Now AffymetrixCelSet$byName(..., chipType="GenomeWideSNP_6,Full") will
+#   work (before chiptypes with tags would give an error).  This is now
+#   done by first locating the CDF for the chip type (with tags).
 # 2009-12-03
 # o BUG FIX: The test for allowing ASCII CDFs or not in setCdf() of an
 #   AffymetrixCelSet was only applied if getOption(aromaSettings, 
