@@ -1,9 +1,14 @@
 setMethodS3("allocateFromCdf", "AromaCellPositionFile", function(static, cdf, path=getPath(cdf), tags="*", ...) {
+  # Argument 'cdf':
   cdf <- Arguments$getInstanceOf(cdf, "AffymetrixCdfFile");
 
-  tags <- strsplit(tags, split=",", fixed=TRUE)[[1]];
+  # Argument 'tags':
+  tags <- Arguments$getTags(tags, collapse=NULL);
+
   chipType <- getChipType(cdf);
-  parts <- strsplit(chipType, split=",", fixed=TRUE)[[1]];
+  parts <- strsplit(chipType, split=",", fixed=TRUE);
+  parts <- unlist(parts, use.names=FALSE);
+
   tags[tags == "*"] <- paste(parts[-1], collapse=",");
   chipType <- parts[1];
   chipType <- gsub(",monocell", "", chipType);
@@ -19,6 +24,9 @@ setMethodS3("allocateFromCdf", "AromaCellPositionFile", function(static, cdf, pa
 
 ############################################################################
 # HISTORY:
+# 2010-03-14 [HB]
+# o BUG FIX: allocateFromCdf() of AromaCellPositionFile would drop all
+#   but the first tag.
 # 2009-02-22 [HB]
 # o Forgot to make allocateFromCdf() of AromaCellPositionFile static.
 # 2009-02-16 [HB]
