@@ -1,4 +1,4 @@
-setMethodS3("doCRMAv1", "AffymetrixCelSet", function(csR, combineAlleles=TRUE, arrays=NULL, ..., ram=NULL, verbose=FALSE) {
+setMethodS3("doCRMAv1", "AffymetrixCelSet", function(csR, shift=+300, combineAlleles=TRUE, arrays=NULL, ..., ram=NULL, verbose=FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
@@ -8,6 +8,9 @@ setMethodS3("doCRMAv1", "AffymetrixCelSet", function(csR, combineAlleles=TRUE, a
     throw(sprintf("Argument 'csR' is not a %s: %s", className, class(csR)[1]));
   }
 
+  # Argument 'shift':
+  shift <- Arguments$getNumeric(shift);
+
   # Argument 'combineAlleles':
   combineAlleles <- Arguments$getLogical(combineAlleles);
 
@@ -54,7 +57,8 @@ setMethodS3("doCRMAv1", "AffymetrixCelSet", function(csR, combineAlleles=TRUE, a
   verbose && print(verbose, gc);
 
   verbose && enter(verbose, "CRMAv1/Probe summarization");
-  plm <- RmaCnPlm(csC, mergeStrands=TRUE, combineAlleles=combineAlleles);
+  plm <- RmaCnPlm(csC, mergeStrands=TRUE, combineAlleles=combineAlleles, 
+                                                            shift=shift);
   verbose && print(verbose, plm);
   if (length(findUnitsTodo(plm)) > 0) {
     # Fit CN probes quickly (~5-10s/array + some overhead)
@@ -131,8 +135,20 @@ setMethodS3("doCRMAv1", "character", function(dataSet, ..., verbose=FALSE) {
 })
 
 
+setMethodS3("doASCRMAv1", "default", function(...) {
+  doCRMAv1(..., combineAlleles=FALSE); 
+})
+
+
 ############################################################################
 # HISTORY:
+# 2010-06-21
+# o Added doASCRMAv1() for a convenient allele-specific CRMAv1 wrapper.
+# 2010-06-07
+# o Added argument shift=+300 to doCRMAv1().
+# 2010-05-17
+# o CORRECTION: doCRMAv1() forgot to shift +300 the signals before 
+#   doing the probe-level summarization.
 # 2010-04-21
 # o BUG FIX: doCRMAv1() for AffymetrixCelSet used undefined 'csN' internally
 #   instead of 'csC'.
